### About

Mahotas is a library of fast computer vision algorithms (all implemented in C++) operates over numpy arrays for convenience.

### Useful Links

- mahotas @ PyPI
- mahotas @ GitHub
- Issue Tracker
- mahotas publication

### Stay Informed

### Cite

If you use mahotas in a publication, please cite:

> Luis Pedro Coelho. Mahotas: Open source software for scriptable computer vision in Journal of Open Research Software, vol 1, 2013. [DOI:10.5334/jors.ac]